@@ -36,7 +36,7 @@
 #  transfer requests.  The server then dispatches "open url" requests
 #  to one or more viewers in the user's web browser.
 
-package require Tclx
+package require Rappture
 
 # load util procedures from this path
 set installdir [file dirname [info script]]
@@ -48,33 +48,7 @@ lappend auto_path $installdir
 # Fork here and run the rest as a background daemon so the parent who
 # launches it the first time doesn't have to wait for this to finish.
 
-proc daemonize {} {
-    close stdin
-    close stdout
-    close stderr
-
-    if {[fork]} { exit 0 }
-
-    set pid2 [id process]
-
-    id process group set
-
-    if {[fork]} { exit 0 }
-
-    # @TODO: This shouldn't be necessary
-    catch { kill $pid2 }
-
-    set fd [open /dev/null r]
-    set fd [open /dev/null w]
-    set fd [open /dev/null w]
-
-    cd /
-    umask 022
-
-    return [id process]
-}
-
-daemonize
+Rappture::daemon
 
 namespace eval filexfer {
     variable fxport 0           ;# server is running on this port
@@ -146,12 +120,12 @@ proc filexfer::init {port cookie} {
 
         #
         # Clean up all files marked for deletion when this program
-        # shuts down.  If we're running in a Hubzero tool session we'll get a
+        # shuts down.  If we're running on nanoHUB, we'll get a
         # SIGHUP signal when it's time to quit.  We should also
-        # catch SIGINT in case this gets killed dead. SIGKILL
-        # can't be caught.
-        signal trap SIGHUP  filexfer::sighup_handler
-        signal trap SIGINT filexfer::sigint_handler
+        # catch SIGKILL in case this gets killed dead.
+        #
+        Rappture::signal SIGHUP filexfer "filexfer::cleanup; exit"
+        Rappture::signal SIGKILL filexfer "filexfer::cleanup; exit"
 
         #
         # Kick off the housekeeping option that will check all
@@ -161,16 +135,6 @@ proc filexfer::init {port cookie} {
     }
 }
 
-proc filexfer::sighup_handler {} {
-    filexfer::cleanup
-    exit
-}
-
-proc filexfer::sigint_handler {} {
-    filexfer::cleanup
-    exit
-}
-
 # ----------------------------------------------------------------------
 # USAGE: filexfer::trigger <token>
 #
@@ -1520,7 +1484,7 @@ proc filexfer::response {cid what args} {
             catch {
                 puts $cid [format "HTTP/1.1 %s
 Date: %s
-Server: hubzero-filexfer
+Server: Rappture
 Connection: %s" $params(-status) $date $params(-connection)]
             }
         }
